[llvm-commits] [llvm] r54754 - /llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp

Devang Patel dpatel at apple.com
Wed Aug 13 13:31:11 PDT 2008


Author: dpatel
Date: Wed Aug 13 15:31:11 2008
New Revision: 54754

URL: http://llvm.org/viewvc/llvm-project?rev=54754&view=rev
Log:
Rename. s/FindIVForUser/FindIVUserForCond/g

Modified:
    llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp

Modified: llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp?rev=54754&r1=54753&r2=54754&view=diff

==============================================================================
--- llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp (original)
+++ llvm/trunk/lib/Transforms/Scalar/LoopStrengthReduce.cpp Wed Aug 13 15:31:11 2008
@@ -177,7 +177,7 @@
                                   IVStrideUse* &CondUse,
                                   const SCEVHandle* &CondStride);
     void OptimizeIndvars(Loop *L);
-    bool FindIVForUser(ICmpInst *Cond, IVStrideUse *&CondUse,
+    bool FindIVUserForCond(ICmpInst *Cond, IVStrideUse *&CondUse,
                        const SCEVHandle *&CondStride);
     bool RequiresTypeConversion(const Type *Ty, const Type *NewTy);
     unsigned CheckForIVReuse(bool, bool, const SCEVHandle&,
@@ -1453,10 +1453,10 @@
   // different starting values, into different PHIs.
 }
 
 /// FindIVForUser - If Cond has an operand that is an expression of an IV,
 /// set the IV user and stride information and return true, otherwise return
 /// false.
-bool LoopStrengthReduce::FindIVForUser(ICmpInst *Cond, IVStrideUse *&CondUse,
+bool LoopStrengthReduce::FindIVUserForCond(ICmpInst *Cond, IVStrideUse *&CondUse,
                                        const SCEVHandle *&CondStride) {
   for (unsigned Stride = 0, e = StrideOrder.size(); Stride != e && !CondUse;
        ++Stride) {
@@ -1713,7 +1713,7 @@
   IVStrideUse *CondUse = 0;
   const SCEVHandle *CondStride = 0;
 
-  if (!FindIVForUser(Cond, CondUse, CondStride))
+  if (!FindIVUserForCond(Cond, CondUse, CondStride))
     return; // setcc doesn't use the IV.
 
   // If possible, change stride and operands of the compare instruction to
@@ -1453,10 +1453,10 @@
 }
 
-/// FindIVForUser - If Cond has an operand that is an expression of an IV,
+/// FindIVUserForCond - If Cond has an operand that is an expression of an IV,
 /// set the IV user and stride information and return true, otherwise return
 /// false.





More information about the llvm-commits mailing list